]> git.sur5r.net Git - i3/i3/commitdiff
Rename tree_close() to tree_close_internal().
authorIngo Bürk <ingo.buerk@tngtech.com>
Mon, 28 Dec 2015 01:58:35 +0000 (20:58 -0500)
committerIngo Bürk <ingo.buerk@tngtech.com>
Mon, 28 Dec 2015 01:58:35 +0000 (20:58 -0500)
It should be clear for callers of this function that this is an internal
function that skips certain validations which might be important. Therefore
we make it clear that this is an internal function by renaming it.

relates to #1761

include/con.h
include/data.h
include/tree.h
src/commands.c
src/con.c
src/floating.c
src/handlers.c
src/randr.c
src/tree.c
src/workspace.c

index 9ed9508a6ef93a658fe1177cd1030d5f52bf1868..655fde7f7f62242c5d29412a1d9ccde1e3f836e8 100644 (file)
@@ -278,7 +278,7 @@ orientation_t con_orientation(Con *con);
 
 /**
  * Returns the container which will be focused next when the given container
- * is not available anymore. Called in tree_close and con_move_to_workspace
+ * is not available anymore. Called in tree_close_internal and con_move_to_workspace
  * to properly restore focus.
  *
  */
index b122dbfdfc88a4eb26f943e14f7beb928a1c159b..9ccc2c2e4075b45ff177e9c93a1d742a24141c7f 100644 (file)
@@ -62,7 +62,7 @@ typedef enum { BS_NORMAL = 0,
                BS_NONE = 1,
                BS_PIXEL = 2 } border_style_t;
 
-/** parameter to specify whether tree_close() and x_window_kill() should kill
+/** parameter to specify whether tree_close_internal() and x_window_kill() should kill
  * only this specific window or the whole X11 client */
 typedef enum { DONT_KILL_WINDOW = 0,
                KILL_WINDOW = 1,
index af3309e9092295c4aec4d55d59308970c98d8e07..4a6404463deac4313592f2953eacbc6155eaae4e 100644 (file)
@@ -57,7 +57,7 @@ bool level_down(void);
 void tree_render(void);
 
 /**
- * Closes the current container using tree_close().
+ * Closes the current container using tree_close_internal().
  *
  */
 void tree_close_con(kill_window_t kill_window);
@@ -78,11 +78,11 @@ void tree_next(char way, orientation_t orientation);
  * recursively while deleting a containers children.
  *
  * The force_set_focus flag is specified in the case of killing a floating
- * window: tree_close() will be invoked for the CT_FLOATINGCON (the parent
+ * window: tree_close_internal() will be invoked for the CT_FLOATINGCON (the parent
  * container) and focus should be set there.
  *
  */
-bool tree_close(Con *con, kill_window_t kill_window, bool dont_kill_parent, bool force_set_focus);
+bool tree_close_internal(Con *con, kill_window_t kill_window, bool dont_kill_parent, bool force_set_focus);
 
 /**
  * Loads tree from ~/.i3/_restart.json (used for in-place restarts).
index d4b2d51c4ac865b0eba605b4c79c5ad13da177ec..eb1834e769188687205aafe662ffb925c62a2fc1 100644 (file)
@@ -1281,7 +1281,7 @@ void cmd_kill(I3_CMD, const char *kill_mode_str) {
     else {
         TAILQ_FOREACH(current, &owindows, owindows) {
             DLOG("matching: %p / %s\n", current->con, current->con->name);
-            tree_close(current->con, kill_mode, false, false);
+            tree_close_internal(current->con, kill_mode, false, false);
         }
     }
 
index 64dbec69bc30941ea0d79e261a3d60cc9834b051..f0353f972393bf6c3eb8a0f05ba06640d37c6172 100644 (file)
--- a/src/con.c
+++ b/src/con.c
@@ -1162,7 +1162,7 @@ orientation_t con_orientation(Con *con) {
 
 /*
  * Returns the container which will be focused next when the given container
* is not available anymore. Called in tree_close and con_move_to_workspace
  * to properly restore focus.
  *
  */
@@ -1678,7 +1678,7 @@ static void con_on_remove_child(Con *con) {
         if (TAILQ_EMPTY(&(con->focus_head)) && !workspace_is_visible(con)) {
             LOG("Closing old workspace (%p / %s), it is empty\n", con, con->name);
             yajl_gen gen = ipc_marshal_workspace_event("empty", con, NULL);
-            tree_close(con, DONT_KILL_WINDOW, false, false);
+            tree_close_internal(con, DONT_KILL_WINDOW, false, false);
 
             const unsigned char *payload;
             ylength length;
@@ -1699,7 +1699,7 @@ static void con_on_remove_child(Con *con) {
     int children = con_num_children(con);
     if (children == 0) {
         DLOG("Container empty, closing\n");
-        tree_close(con, DONT_KILL_WINDOW, false, false);
+        tree_close_internal(con, DONT_KILL_WINDOW, false, false);
         return;
     }
 }
index 77bc9e17989b37a3a6ade3e4685dca65d30e801b..3aa423641db09cc0596f2d6892097e1bbbfdfaa6 100644 (file)
@@ -162,7 +162,7 @@ void floating_enable(Con *con, bool automatic) {
     }
 
     /* 1: detach the container from its parent */
/* TODO: refactor this with tree_close() */
     TAILQ_REMOVE(&(con->parent->nodes_head), con, nodes);
     TAILQ_REMOVE(&(con->parent->focus_head), con, focused);
 
@@ -180,7 +180,7 @@ void floating_enable(Con *con, bool automatic) {
     nc->layout = L_SPLITH;
     /* We insert nc already, even though its rect is not yet calculated. This
      * is necessary because otherwise the workspace might be empty (and get
* closed in tree_close()) even though it’s not. */
     TAILQ_INSERT_TAIL(&(ws->floating_head), nc, floating_windows);
     TAILQ_INSERT_TAIL(&(ws->focus_head), nc, focused);
 
@@ -188,7 +188,7 @@ void floating_enable(Con *con, bool automatic) {
     if ((con->parent->type == CT_CON || con->parent->type == CT_FLOATING_CON) &&
         con_num_children(con->parent) == 0) {
         DLOG("Old container empty after setting this child to floating, closing\n");
-        tree_close(con->parent, DONT_KILL_WINDOW, false, false);
+        tree_close_internal(con->parent, DONT_KILL_WINDOW, false, false);
     }
 
     char *name;
@@ -333,7 +333,7 @@ void floating_disable(Con *con, bool automatic) {
     /* 2: kill parent container */
     TAILQ_REMOVE(&(con->parent->parent->floating_head), con->parent, floating_windows);
     TAILQ_REMOVE(&(con->parent->parent->focus_head), con->parent, focused);
-    tree_close(con->parent, DONT_KILL_WINDOW, true, false);
+    tree_close_internal(con->parent, DONT_KILL_WINDOW, true, false);
 
     /* 3: re-attach to the parent of the currently focused con on the workspace
      * this floating con was on */
index 6f08d25c5500f83a9079baef37ec7730e4344c9b..6cbc54f230d0dfc2864be17ed6fcf35e45e73461 100644 (file)
@@ -503,7 +503,7 @@ static void handle_unmap_notify_event(xcb_unmap_notify_event_t *event) {
         goto ignore_end;
     }
 
-    tree_close(con, DONT_KILL_WINDOW, false, false);
+    tree_close_internal(con, DONT_KILL_WINDOW, false, false);
     tree_render();
 
 ignore_end:
@@ -878,7 +878,7 @@ static void handle_client_message(xcb_client_message_event_t *event) {
             if (event->data.data32[0])
                 last_timestamp = event->data.data32[0];
 
-            tree_close(con, KILL_WINDOW, false, false);
+            tree_close_internal(con, KILL_WINDOW, false, false);
             tree_render();
         } else {
             DLOG("Couldn't find con for _NET_CLOSE_WINDOW request. (window = %d)\n", event->window);
index 81a33e622bb3cc9d3db67cd87c654b5baf5d6ad0..6753f8a67eb7724f4c8a41d7a40be83303279cc6 100644 (file)
@@ -741,7 +741,7 @@ void randr_query_outputs(void) {
                     if (current != next && TAILQ_EMPTY(&(current->focus_head))) {
                         /* the workspace is empty and not focused, get rid of it */
                         DLOG("Getting rid of current = %p / %s (empty, unfocused)\n", current, current->name);
-                        tree_close(current, DONT_KILL_WINDOW, false, false);
+                        tree_close_internal(current, DONT_KILL_WINDOW, false, false);
                         continue;
                     }
                     DLOG("Detaching current = %p / %s\n", current, current->name);
@@ -783,7 +783,7 @@ void randr_query_outputs(void) {
                 }
 
                 DLOG("destroying disappearing con %p\n", output->con);
-                tree_close(output->con, DONT_KILL_WINDOW, true, false);
+                tree_close_internal(output->con, DONT_KILL_WINDOW, true, false);
                 DLOG("Done. Should be fine now\n");
                 output->con = NULL;
             }
index 1d06d87481bc42b53cecb9748db111d6f0348369..e296a9819bdae297e0f86a259b62680c060232a9 100644 (file)
@@ -185,11 +185,11 @@ static bool _is_con_mapped(Con *con) {
  * recursively while deleting a containers children.
  *
  * The force_set_focus flag is specified in the case of killing a floating
* window: tree_close() will be invoked for the CT_FLOATINGCON (the parent
  * container) and focus should be set there.
  *
  */
-bool tree_close(Con *con, kill_window_t kill_window, bool dont_kill_parent, bool force_set_focus) {
+bool tree_close_internal(Con *con, kill_window_t kill_window, bool dont_kill_parent, bool force_set_focus) {
     bool was_mapped = con->mapped;
     Con *parent = con->parent;
 
@@ -219,7 +219,7 @@ bool tree_close(Con *con, kill_window_t kill_window, bool dont_kill_parent, bool
     for (child = TAILQ_FIRST(&(con->nodes_head)); child;) {
         nextchild = TAILQ_NEXT(child, nodes);
         DLOG("killing child=%p\n", child);
-        if (!tree_close(child, kill_window, true, false))
+        if (!tree_close_internal(child, kill_window, true, false))
             abort_kill = true;
         child = nextchild;
     }
@@ -310,7 +310,7 @@ bool tree_close(Con *con, kill_window_t kill_window, bool dont_kill_parent, bool
      * underlying container, see ticket #660.
      *
      * Rendering has to be avoided when dont_kill_parent is set (when
* tree_close calls itself recursively) because the tree is in a
      * non-renderable state during that time. */
     if (!dont_kill_parent)
         tree_render();
@@ -320,7 +320,7 @@ bool tree_close(Con *con, kill_window_t kill_window, bool dont_kill_parent, bool
 
     if (con_is_floating(con)) {
         DLOG("Container was floating, killing floating container\n");
-        tree_close(parent, DONT_KILL_WINDOW, false, (con == focused));
+        tree_close_internal(parent, DONT_KILL_WINDOW, false, (con == focused));
         DLOG("parent container killed\n");
     }
 
@@ -363,7 +363,7 @@ bool tree_close(Con *con, kill_window_t kill_window, bool dont_kill_parent, bool
 }
 
 /*
* Closes the current container using tree_close().
  *
  */
 void tree_close_con(kill_window_t kill_window) {
@@ -379,7 +379,7 @@ void tree_close_con(kill_window_t kill_window) {
         for (child = TAILQ_FIRST(&(focused->focus_head)); child;) {
             nextchild = TAILQ_NEXT(child, focused);
             DLOG("killing child=%p\n", child);
-            tree_close(child, kill_window, false, false);
+            tree_close_internal(child, kill_window, false, false);
             child = nextchild;
         }
 
@@ -387,7 +387,7 @@ void tree_close_con(kill_window_t kill_window) {
     }
 
     /* Kill con */
-    tree_close(focused, kill_window, false, false);
+    tree_close_internal(focused, kill_window, false, false);
 }
 
 /*
@@ -773,7 +773,7 @@ void tree_flatten(Con *con) {
 
     /* 4: close the redundant cons */
     DLOG("closing redundant cons\n");
-    tree_close(con, DONT_KILL_WINDOW, true, false);
+    tree_close_internal(con, DONT_KILL_WINDOW, true, false);
 
     /* Well, we got to abort the recursion here because we destroyed the
      * container. However, if tree_flatten() is called sufficiently often,
index dc0a596d53780ecf8345dc929f9084211aed6d4b..923bfc83a4d289c061fd5dc49e5f376a09c1114b 100644 (file)
@@ -442,7 +442,7 @@ static void _workspace_show(Con *workspace) {
 
     DLOG("old = %p / %s\n", old, (old ? old->name : "(null)"));
     /* Close old workspace if necessary. This must be done *after* doing
* urgency handling, because tree_close() will do a con_focus() on the next
      * client, which will clear the urgency flag too early. Also, there is no
      * way for con_focus() to know about when to clear urgency immediately and
      * when to defer it. */
@@ -451,7 +451,7 @@ static void _workspace_show(Con *workspace) {
         if (!workspace_is_visible(old)) {
             LOG("Closing old workspace (%p / %s), it is empty\n", old, old->name);
             yajl_gen gen = ipc_marshal_workspace_event("empty", old, NULL);
-            tree_close(old, DONT_KILL_WINDOW, false, false);
+            tree_close_internal(old, DONT_KILL_WINDOW, false, false);
 
             const unsigned char *payload;
             ylength length;
@@ -1162,7 +1162,7 @@ orientation_t con_orientation(Con *con) {
 /*
  * Returns the container which will be focused next when the given container
- * is not available anymore. Called in tree_close and con_move_to_workspace
+ * is not available anymore. Called in tree_close_internal and con_move_to_workspace
  * to properly restore focus.
  *
@@ -162,7 +162,7 @@ void floating_enable(Con *con, bool automatic) {
 
     /* 1: detach the container from its parent */
-    /* TODO: refactor this with tree_close() */
+    /* TODO: refactor this with tree_close_internal() */
     TAILQ_REMOVE(&(con->parent->nodes_head), con, nodes);
     TAILQ_REMOVE(&(con->parent->focus_head), con, focused);
@@ -180,7 +180,7 @@ void floating_enable(Con *con, bool automatic) {
     /* We insert nc already, even though its rect is not yet calculated. This
      * is necessary because otherwise the workspace might be empty (and get
-     * closed in tree_close()) even though it’s not. */
+     * closed in tree_close_internal()) even though it’s not. */
     TAILQ_INSERT_TAIL(&(ws->floating_head), nc, floating_windows);
     TAILQ_INSERT_TAIL(&(ws->focus_head), nc, focused);
@@ -185,11 +185,11 @@ static bool _is_con_mapped(Con *con) {
  *
  * The force_set_focus flag is specified in the case of killing a floating
- * window: tree_close() will be invoked for the CT_FLOATINGCON (the parent
+ * window: tree_close_internal() will be invoked for the CT_FLOATINGCON (the parent
  * container) and focus should be set there.
  *
@@ -310,7 +310,7 @@ bool tree_close(Con *con, kill_window_t kill_window, bool dont_kill_parent, bool
      *
      * Rendering has to be avoided when dont_kill_parent is set (when
-     * tree_close calls itself recursively) because the tree is in a
+     * tree_close_internal calls itself recursively) because the tree is in a
      * non-renderable state during that time. */
     if (!dont_kill_parent)
@@ -363,7 +363,7 @@ bool tree_close(Con *con, kill_window_t kill_window, bool dont_kill_parent, bool
 
 /*
- * Closes the current container using tree_close().
+ * Closes the current container using tree_close_internal().
  *
  */
@@ -442,7 +442,7 @@ static void _workspace_show(Con *workspace) {
     DLOG("old = %p / %s\n", old, (old ? old->name : "(null)"));
     /* Close old workspace if necessary. This must be done *after* doing
-     * urgency handling, because tree_close() will do a con_focus() on the next
+     * urgency handling, because tree_close_internal() will do a con_focus() on the next
      * client, which will clear the urgency flag too early. Also, there is no
      * way for con_focus() to know about when to clear urgency immediately and